@@ -343,10 +343,10 @@ class CallNotify(hildondesktop.StatusMenuItem):
                 cur = conn.cursor()
                 if isSms:
                         #Nokia changed the event number from 7 to 11 and also combined the incomming and outgoing sms's
-                        cur.execute("select count(id) from Events where event_type_id = 11 and outgoing = 0")
+                        cur.execute("select count(id) from Events where event_type_id = 7 and outgoing = 0")
                 else:
                         #Nokia changed the event from 3 to 2
-                        cur.execute("select count(id) from Events where event_type_id = 2")
+                        cur.execute("select count(id) from Events where event_type_id = 3 and outgoing = 0")
 		return cur.fetchone()[0]
 
     def show(self):
@@ -400,9 +400,9 @@ hd_plugin_type = CallNotify
 # Uncomment from "if __name__..." to "gtk.main()" if running from CLI as:
 # "run-standalone.sh python CallNotify.py"
 
-if __name__=="__main__":
-		gobject.type_register(hd_plugin_type)
-		obj = gobject.new(hd_plugin_type, plugin_id="plugid_id")
-		obj.show_all()
-	 	gtk.main()
+#if __name__=="__main__":
+#		gobject.type_register(hd_plugin_type)
+#		obj = gobject.new(hd_plugin_type, plugin_id="plugid_id")
+#		obj.show_all()
+#	 	gtk.main()
 
